Changelog
=========


1.1 (2018-01-04)
----------------

- Added field `to_sign` to the behavior.
  [gbastien]

1.0 (2017-05-30)
----------------

- Moved version attribute to the scan tab.
  [gbastien]
- Move the signed attribute from IDmsFile schema
  [mpeeters]
- Added signed index
  [sgeulette]

0.4 (2016-04-20)
----------------

- Add version attribute.
  [sgeulette]

0.3.3 (2015-11-24)
------------------

- Don't store None in catalog. [sgeulette]

0.3.2 (2015-06-05)
------------------

- Corrected MANIFEST [sgeulette]

0.3.1 (2015-06-05)
------------------

- Modified scan_id index [sgeulette]

0.3 (2014-11-28)
----------------

- Added scan_id as index [sgeulette]

0.2.1 (2014-09-02)
------------------

- Updated changes.
- Corrected manifest.

0.2 (2014-04-15)
----------------

- renamed IScan in IScanFields.
- changed zcml description of behavior
- translate the title and description of the behavior in the interface.
- delete the folder content.
- moved the zcml definition of import step in profile.
- correct the manifest.
- renamed "scan_user" to "operator".

0.1 (2014-04-14)
----------------

- Initial release.
  [fngaha]
